The Python REST client project
==============================

A Python project for sending requests to REST APIs.
---------------------------------------------------------------

This project aims to build ORM wrappers around REST interfaces, by separating the configuration 
from the business logic.
